summary refs log tree commit diff stats
path: root/compiler/semtempl.nim
diff options
context:
space:
mode:
authorArne Döring <arne.doering@gmx.net>2019-05-11 10:11:08 +0200
committerAndreas Rumpf <rumpf_a@web.de>2019-05-11 10:11:08 +0200
commitb92fd30282f5063117ae4616aba366f5f445ed8e (patch)
tree6b4ac1523c4247a22c9900bf8c5a7166d91f9335 /compiler/semtempl.nim
parentf03391d4775bffb3f51c9be47baf04f8b49e2900 (diff)
downloadNim-b92fd30282f5063117ae4616aba366f5f445ed8e.tar.gz
rename tyExpr/tyStmt to tyUntyped/tyTyped (#11227)
Diffstat (limited to 'compiler/semtempl.nim')
-rw-r--r--compiler/semtempl.nim10
1 files changed, 5 insertions, 5 deletions
diff --git a/compiler/semtempl.nim b/compiler/semtempl.nim
index 4b283f793..01a0a41bb 100644
--- a/compiler/semtempl.nim
+++ b/compiler/semtempl.nim
@@ -595,21 +595,21 @@ proc semTemplateDef(c: PContext, n: PNode): PNode =
     for i in 1 .. s.typ.n.len-1:
       let param = s.typ.n.sons[i].sym
       param.flags.excl sfGenSym
-      if param.typ.kind != tyExpr: allUntyped = false
+      if param.typ.kind != tyUntyped: allUntyped = false
     if sonsLen(gp) > 0:
       if n.sons[genericParamsPos].kind == nkEmpty:
         # we have a list of implicit type parameters:
         n.sons[genericParamsPos] = gp
     # no explicit return type? -> use tyStmt
     if n.sons[paramsPos].sons[0].kind == nkEmpty:
       # use ``stmt`` as implicit result type
-      s.typ.sons[0] = newTypeS(tyStmt, c)
+      s.typ.sons[0] = newTypeS(tyTyped, c)
       s.typ.n.sons[0] = newNodeIT(nkType, n.info, s.typ.sons[0])
   else:
     s.typ = newTypeS(tyProc, c)
     # XXX why do we need tyStmt as a return type again?
     s.typ.n = newNodeI(nkFormalParams, n.info)
-    rawAddSon(s.typ, newTypeS(tyStmt, c))
+    rawAddSon(s.typ, newTypeS(tyTyped, c))
     addSon(s.typ.n, newNodeIT(nkType, n.info, s.typ.sons[0]))
   if allUntyped: incl(s.flags, sfAllUntyped)
   if n.sons[patternPos].kind != nkEmpty:
@@ -595,21 +595,21 @@ proc semTemplateDef(c: PContext, n: PNode): PNode =
         # we have a list of implicit type parameters:
         n.sons[genericParamsPos] = gp
-    # no explicit return type? -> use tyStmt
+    # no explicit return type? -> use tyTyped
     if n.sons[paramsPos].sons[0].kind == nkEmpty:
       # use ``stmt`` as implicit result type
@@ -595,21 +595,21 @@ proc semTemplateDef(c: PContext, n: PNode): PNode =
   else:
     s.typ = newTypeS(tyProc, c)
-    # XXX why do we need tyStmt as a return type again?
+    # XXX why do we need tyTyped as a return type again?
     s.typ.n = newNodeI(nkFormalParams, n.info)